==> smarts-0.5.1-py3-none-any.whl: smarts/core/data_model.py <==
# Copyright (C) 2020. Huawei Technologies Co., Ltd. All rights reserved.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from dataclasses import dataclass, field
from typing import Any, Dict

from smarts.core.agent import AgentSpec
from smarts.zoo.registry import make


@dataclass
class SocialAgent:
    """A serializable representation of a social agent."""

    id: str
    name: str
    is_boid: bool
    is_boid_keep_alive: bool
    agent_locator: str
    policy_kwargs: Dict[str, Any] = field(default_factory=dict)
    initial_speed: float = None

    def to_agent_spec(self) -> AgentSpec:
        """Generate an agent spec."""
        return make(locator=self.agent_locator, **self.policy_kwargs)

==> smarts-0.6.0-py3-none-any.whl: smarts/core/data_model.py <==
# Copyright (C) 2020. Huawei Technologies Co., Ltd. All rights reserved.
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.
from dataclasses import dataclass, field
from typing import Any, Dict, Optional

from smarts.zoo.agent_spec import AgentSpec
from smarts.zoo.registry import make


@dataclass
class SocialAgent:
    """A serializable representation of a social agent."""

    id: str
    name: str
    is_boid: bool
    is_boid_keep_alive: bool
    agent_locator: str
    policy_kwargs: Dict[str, Any] = field(default_factory=dict)
    initial_speed: Optional[float] = None

    def to_agent_spec(self) -> AgentSpec:
        """Generate an agent spec."""
        return make(locator=self.agent_locator, **self.policy_kwargs)
